# Changelog

- 0.1.0
  - added bash guide with -b
  - added tko guide with -g
- 0.0.9
  - removed tab from wdir.resume
  - fixed type in whitespace
  - added mismatch arrow
  - added -g option to show simple guide
- 0.0.8
  - add colors in diff inside the line
- 0.0.7
  - fix esbuild incompatibility in windows
- 0.0.6
  - fix wls incompatibility
- 0.0.5
  - adding draft models to down
  - removing conversion in js and ts entry code
  - adding --config to tko
  - changing @ for _ in downloaded problems folder name
